@@ -120,7 +120,7 @@ def update_the_database(db, filename):
         db.create_or_update_history(table_name=filename.split('/')[-3], url=url)
         db.delete_hash(hash=filename.split('/')[-1])
         db.delete_smilitaries(table_name=filename.split('/')[-3], url=url)
-        logger.info("Successfully updated database  ")
+        # logger.info("Successfully updated database  ")
         return True
     except Exception as e:
         logger.error("Erreur updating the database ... (%s) " % e)
@@ -207,7 +207,7 @@ def remove(db, filename):
             os.remove(filename)
             return 0
         else:
-            logger.info("File doesn't exist... Nothing to remove")
+            # logger.info("File doesn't exist... Nothing to remove")
             return -1
     except:
         logger.error("Error when removing file '" + filename + "'...")
@@ -268,7 +268,7 @@ def download_resized_image(url, filename):
                      'Chrome/83.0.4103.97 Safari/537.36')
     # As long as the file is opened in binary mode, both Python 2 and Python 3
     # can write response body to it without decoding.
-    logger.info("******** Downloading image..")
+    # logger.info("******** Downloading image..")
     start = time.process_time()
     try:
         res = all(ord(c) < 128 for c in url)
@@ -278,7 +278,7 @@ def download_resized_image(url, filename):
             url = urllib.parse.urlparse(url)
             url = url.scheme + "://" + url.netloc + urllib.parse.quote(url.path)
             resize_and_retrieve(url.replace(' ', '+'), filename)
-        logger.info("*** download time taken" + str(time.process_time() - start))
+        # logger.info("*** download time taken" + str(time.process_time() - start))
         return filename
     except Exception as e:
         logger.error("Error when downloading/writing download_resized_image 1 file %s error %s ..." % (filename, e))
@@ -286,7 +286,7 @@ def download_resized_image(url, filename):
         url_extension = image_extension(url)
         real_extension = imghdr.what(filename)
     except Exception as e:
-        logger.info("Exception file %s " % e)
+        # logger.info("Exception file %s " % e)
         return None
     if real_extension != url_extension:
         file_hash = filename.split('.')[0]
@@ -300,7 +300,7 @@ def download_resized_image(url, filename):
                 url = urllib.parse.urlparse(url)
                 url = url.scheme + "://" + url.netloc + urllib.parse.quote(url.path)
                 resize_and_retrieve(url.replace(' ', '+'), file_hash + '.' + real_extension)
-            logger.info("*** download time taken" + str(time.process_time() - start))
+            # logger.info("*** download time taken" + str(time.process_time() - start))
             return file_hash + '.' + real_extension
         except Exception as e:
             logger.error("Error when downloading/writing file download_resized_image 2 %s error %s ..."
@@ -377,7 +377,7 @@ def download_or_remove(urls, each_url_product, product_id, product_url_mobile, c
         extention = image_extension(url)
         filename = hash_file + '.' + extention
         fichier = path_out + '/' + filename
-        logger.info("Retrieving image from URL...")
+        # logger.info("Retrieving image from URL...")
 
         db.create_client_products_table(replace_special_caractere(customer_name).replace(' ', '_'))
 
@@ -387,9 +387,9 @@ def download_or_remove(urls, each_url_product, product_id, product_url_mobile, c
             logger.info("File exists but size is 0... Download again!")
             start = time.process_time()
             download_resized_image(url, fichier)
-            logger.info("*** download time taken" + str(time.process_time() - start))
+            # logger.info("*** download time taken" + str(time.process_time() - start))
         else:
-            logger.info("File doesn't exist... Downloading...")
+            # logger.info("File doesn't exist... Downloading...")
             download_resized_image(url, fichier)
         if fichier.split('/')[-2] == project_name:
             file_azure = input_azure + fichier.split('/')[-1]
@@ -453,7 +453,7 @@ def get_client_code_country(adress):
     try:
         response = DbIpCity.get(adress, api_key='free')
         code_country = response.country
-        logger.info(" The code country is %s" % code_country)
+        # logger.info(" The code country is %s" % code_country)
     except Exception as e:
 
         logger.error("Cannot get The code country for address %s" % adress)
@@ -469,7 +469,7 @@ def get_client_country(adress):
     else:
         response = DbIpCity.get(adress, api_key='free')
         country = response.city
-        logger.info(" The code country is %s" % country)
+        # logger.info(" The code country is %s" % country)
     return country
 
 
@@ -500,9 +500,10 @@ def get_api_version_shopify():
 
 
 def get_valid_post(customer, customer_type):
+    import calendar
     year = datetime.datetime.today().strftime("%Y")
     month = datetime.datetime.today().strftime("%m")
-    logger.info('counter for client %s for year %s and month %s' % (customer, year, month))
+    # logger.info('counter for client %s for year %s and month %s' % (customer, year, month))
     last_day = calendar.monthrange(int(year), int(month))[1]
     date_start = "%s-%s-01" % (year, month)
     date_fin = "%s-%s-%s" % (year, month, last_day)
@@ -510,28 +511,31 @@ def get_valid_post(customer, customer_type):
     if not post_counter:
         post_counter = 0
     plan_client = db.get_client_payment(customer, customer_type)[5]
-    max_post = db.max_post(plan_client)[0]
-    return max_post < post_counter
+    if plan_client[1] == 'FREE':
+        max_post = db.max_post(plan_client)[0]
+        return max_post < post_counter
+    else:
+        return False
 
 
 def max_number_product_exceeded(customer_name, customer_type, body):
-    try:
-        payment = db.get_client_payment(customer_name, customer_type)
-        plan_name = payment[5]
-        plan = db.get_plan_form_name(plan_name)
-        max_number_training_image = int(plan[4])
-        somme = 0
-        for category in body.json()[customer_name + '_' + customer_type]:
-            somme += len(category['Photos'])
-        logger.info("products count %s for file %s client %s type %s" % (somme, body, customer_name, customer_type))
-        if somme > max_number_training_image:
-            return True
-        else:
+        try:
+            payment = db.get_client_payment(customer_name, customer_type)
+            plan_name = payment[5]
+            plan = db.get_plan_form_name(plan_name)
+            max_number_training_image = int(plan[4])
+            somme = 0
+            for category in body.json()[customer_name + '_' + customer_type]:
+                somme += len(category['Photos'])
+            # logger.info("products count %s for file %s client %s type %s" % (somme, body, customer_name, customer_type))
+            if somme > max_number_training_image and plan_name == 'FREE':
+                return True
+            else:
+                return False
+        except Exception as e:
+            logger.error("error in getting products count for client %s with type %s file %s error %s"
+                         % (customer_name, customer_type, body, e))
             return False
-    except Exception as e:
-        logger.error("error in getting products count for client %s with type %s file %s error %s"
-                     % (customer_name, customer_type, body, e))
-        return False
 
 
 def get_count_product_validation(token, url_shop, plan):
@@ -673,6 +677,7 @@ def count_product(token, url_shop):
     except:
         return 0
 
+
 # TO BE MODIFIED TO MATCH THE LATEST ONE AND TO BE IMPORTED EVERYWHERE NEEDED IN BACKEND
 def fine_tune(IMG_HEIGHT, IMG_WIDTH, NUM_CLASSES):
 
@@ -712,8 +717,8 @@ def verification_of_images(customer_name, customer_type, project_name):
             ext = imghdr.what(path + file_obj)
             if (ext != file_obj.split(".")[1]) or (ext is None):
                 os.remove(path + file_obj)
-                logger.info("Deleting_image %s as it contains %s encoding - %s "
-                            % (file_obj, ext, file_obj.split('.')))
+                # logger.info("Deleting_image %s as it contains %s encoding - %s "
+                #             % (file_obj, ext, file_obj.split('.')))
     else:
         for j in next(os.walk(path))[1]:
             filelist = os.listdir(path + j + "/")
@@ -722,8 +727,8 @@ def verification_of_images(customer_name, customer_type, project_name):
                 ext = imghdr.what(path + j + "/" + file_obj)
                 if (ext != file_obj.split(".")[1]) or (ext is None):
                     os.remove(path + j + "/" + file_obj)
-                    logger.info("Deleting_image %s as it contains %s encoding - %s "
-                                % (file_obj, ext, file_obj.split('.')[1]))
+                    # logger.info("Deleting_image %s as it contains %s encoding - %s "
+                    #             % (file_obj, ext, file_obj.split('.')[1]))
 
 
 def load_vectors_from_local(vectors, users):
@@ -744,29 +749,29 @@ def load_vectors_from_local(vectors, users):
                             try:
                                 vector_name = vector.split('.parquet')[0]
                                 if vector_name not in vectors.keys():
-                                    logger.info(
-                                        'Vector to load  =====> %s' % (vector))
+                                    # logger.info(
+                                    #     'Vector to load  =====> %s' % (vector))
                                     vector_data = dd.read_parquet(vector_path + project + '/' + vector,
                                                                   engine='pyarrow')
 
                                     vectors[vector_name] = vector_data
                                     if vector_data is not None:
                                         vectors[vector_name] = vector_data
-                                        logger.info('Vector %s  loaded successfully for client %s '
-                                                            % (vector_name, str(user[1])))
-                                    else:
-                                        logger.info(
-                                                    'Vector %s not loaded for client %s vector is None'
-                                                    % (vector_name, str(user[1])))
+                                        # logger.info('Vector %s  loaded successfully for client %s '
+                                        #                     % (vector_name, str(user[1])))
+                                    # else:
+                                    #     logger.info(
+                                    #                 'Vector %s not loaded for client %s vector is None'
+                                    #                 % (vector_name, str(user[1])))
                             except Exception as e:
                                 logger.warning("Vector not loaded %s error %s" %(vector, e))
                     else:
-                        logger.info('Status Project not 2 %s %s' % (project, status))
+                        # logger.info('Status Project not 2 %s %s' % (project, status))
                         continue
         except Exception as e:
             logger.warning("Can't get the parquet file for client %s with domaine %s error %s"
                            % (str(user[1]), str(user[8]), e))
-    logger.info("Vectors keys : %s" % vectors.keys())
+    # logger.info("Vectors keys : %s" % vectors.keys())
     return vectors
 
 
@@ -797,8 +802,6 @@ def befor_month(number):
         return "11"
 
 
-
-
 def week_of_month(dt):
     first_day = dt.replace(day=1)
     dom = dt.day
@@ -823,7 +826,6 @@ def create_table_plan_and_plan():
 
 def shopify_payment_billing(customer_name, customer_type, customer_email, url_cms, token_cms, plan):
 
-
     headers = {
         "X-Shopify-Access-Token": token_cms,
         "Content-Type": "application/json"
@@ -845,18 +847,15 @@ def shopify_payment_billing(customer_name, customer_type, customer_email, url_cm
                                       % (api_version, payment_client[6])
                     response_delete = requests.delete("https://{0}{1}".format(url_cms, delete_endpoint),
                                                       headers=headers)
-                    if response_delete.status_code == 200:
-                        logger.info("========>payment deleted %s " % payment_client[6])
+                    # if response_delete.status_code == 200:
+                        # logger.info("========>payment deleted %s " % payment_client[6])
         else:
             previous_payment = False
     except Exception as e:
         logger.error("Exception deleting old payment %s for client %s %s " % (e, customer_name, customer_type))
-    if plan == 'STANDARD':
-        price = 99.0
-    elif plan == 'PREMIUM':
-        price = 299.0
-    else:
-        price = 499.0
+
+    price = 99.0
+
     price_dollar = round(price_converter.convert(price, 'EUR', 'USD'))
     endpoint = "/admin/api/%s/recurring_application_charges.json" % api_version
     json_post = {
@@ -870,27 +869,28 @@ def shopify_payment_billing(customer_name, customer_type, customer_email, url_cm
         json_post['recurring_application_charge']['test'] = 'true'
         json_post['recurring_application_charge']['trial_days'] = 1000
     if not previous_payment:
-        json_post['recurring_application_charge']['trial_days'] = 30
-        total = price * 11
+        json_post['recurring_application_charge']['trial_days'] = 0
+        total = price
     else:
-        total = price * 12
-    logger.info('===========> json to post %s total to pay %s' % (json.dumps(json_post), total))
+        total = price
+    # logger.info('===========> json to post %s total to pay %s' % (json.dumps(json_post), total))
     charge_shopify_api = requests.post("https://{0}{1}".format(url_cms, endpoint), headers=headers, json=json_post)
     if charge_shopify_api.status_code == 201:
         response = json.loads(charge_shopify_api.text)
         transaction_id = response.get('recurring_application_charge', {}).get('id', None)
         url_confirmation = response.get('recurring_application_charge', {}).get('confirmation_url', '')
-        logger.info("====>recurring_application_charge_signup_url_confirmation %s " % transaction_id)
+        # logger.info("====>recurring_application_charge_signup_url_confirmation %s " % transaction_id)
         date = datetime.datetime.today().strftime("%Y-%m-%d %H:%M:%S")
-        db.update_client_payement(customer_name, customer_type, date, plan, 0, 'paypal', total)
+        db.update_client_payement(customer_name, customer_type, date, plan, 1, 'paypal', total)
         db.update_transction_id(customer_name, customer_type, str(transaction_id), plan, date, 'paypal')
         db.update_url_confirmation(customer_name, customer_type, 'shopify', url_cms, token_cms, url_confirmation)
+        create_or_update_user_apikey(user=customer_name, period_in_hours=30)
         return url_confirmation
     else:
         try:
             send_payment_email(customer_email)
         except Exception as e:
-            logger.info("exception in sending email shopify_payment_billing..." + str(e))
+            logger.error("exception in sending email shopify_payment_billing..." + str(e))
         return ''
 
 
@@ -931,8 +931,8 @@ def get_url_confirmation_expiration(customer, customer_type, customer_email):
                 create_or_update_user_apikey(user=customer, period_in_hours=8040)
                 db.update_url_confirmation(customer, customer_type, 'shopify', cms_details[5], cms_details[6],
                                            '')
-                logger.info("Client shopify %s accept the payment and  it is activated %s %s"
-                            % (cms_details[5], customer, customer_type))
+                # logger.info("Client shopify %s accept the payment and  it is activated %s %s"
+                #             % (cms_details[5], customer, customer_type))
 
             return None
         else:
@@ -999,10 +999,10 @@ def image_treatement_to_vector(model, image_path, hash_image):
 
 def add_layer_to_vgg(customer_name, customer_type):
     parameters = db.get_training_parameters(customer_name, customer_type, "similars")
-    logger.info('--------------------------------------------------------')
+    # logger.info('--------------------------------------------------------')
     include_top = parameters.get('vectors').get('include_top', False)
     classes = parameters.get('vectors').get('classes_numbers', 1000)
-    logger.info('--------------------------------------------------------')
+    # logger.info('--------------------------------------------------------')
     try:
         if include_top:
             logger.info("====> Loading model with include_top True and classes %s" % classes)
@@ -1046,15 +1046,10 @@ def get_images_from_db_vptree(images, customer_name, project_name):
         url_image = db.get_url_from_hash_client_table(replace_special_caractere(customer_name).replace(' ', '_'),
                                                       project_name, i['image'].split('/')[-1])
         if url_image is None:
-            print('No image for %s' %i['image'])
             continue
-        if any(i['image'] in image for image in url_image[3].split(' ')):
-            print(i)
         for image in url_image[3].split(' '):
             if i['image'] in image:
-                print(image)
                 index_hash = url_image[3].split(' ').index(image)
-                print(index_hash)
                 value_image = {'url_image': url_image[1].split(' ')[index_hash],
                                'score': int(round(i['score'], 2) * 10 * 10) if i['score'] < 1 else int(round(i['score'], 2) * 10 ),
                                'url_produit': url_image[2] if url_image[2] else '',
