@@ -821,10 +821,11 @@ def payment_client(customer, customer_type, email,  plan_name, methode_payment,
     price_month = float(plan[3] / 12)
     tva_number = details_client[8]
     if vatnumber.check_vat_fr(tva_number):
-        price_month_tva = price_month + (price_month * 0.2)
-        total = price_month_tva * 11 if payment[7] else price_month_tva * 12
+        total = price_month + (price_month * 0.2)
+        # total = price_month_tva * 11 if payment[7] else price_month_tva * 12
     else:
-        total = price_month * 11 if payment[7] else price_month * 12
+        # total = price_month * 11 if payment[7] else price_month * 12
+        total = price_month
     if methode_payment == 'stripe':
 
         db.update_client_payement(customer, customer_type, date, plan_name, 1, 'stripe', total)
@@ -841,7 +842,7 @@ def payment_client(customer, customer_type, email,  plan_name, methode_payment,
                                  int(datetime.datetime.today().strftime("%d"))) - \
                             date(int(payment[3].strftime("%Y")), int(payment[3].strftime("%m")),
                                  int(payment[3].strftime("%d")))
-        period_in_hours = (365 - int(period_for_client.days)) * 24
+        period_in_hours = (30 - int(period_for_client.days)) * 24
         create_or_update_user_apikey(user=customer, period_in_hours=period_in_hours)
         db.update_date_payment(customer, customer_type, datetime.datetime.today().strftime("%Y-%m-%d"))
         if stripe_error:
